==> nextcloud-31.0.4-1.0-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/cs.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Veřejný odkaz",
    "Photos" : "Fotky",
    "On This Day" : "V tento den",
    "Your memories under your control" : "Vaše vzpomínky pod vaší kontrolou",
    "All media" : "Veškerá média",
    "Videos" : "Videa",
    "Albums" : "Alba",
    "Collaborative albums" : "Alba pro spolupráci",
    "People" : "Lidé",
    "Folders" : "Složky",
    "Favorites" : "Oblíbené",
    "On this day" : "V tento den",
    "Shared with you" : "Sdíleno s vámi",
    "Tags" : "Štítky",
    "Places" : "Místa",
    "Map" : "Mapa",
    "Photos settings" : "Nastavení pro Fotky",
    "Mark selection as favorite" : "Označit vybrané jako oblíbené",
    "Add selection to favorites" : "Přidat vybrané do oblíbených",
    "Remove selection from favorites" : "Odebrat vybrané z oblíbených",
    "Name of the album" : "Název alba",
    "Location of the album" : "Umístění alba",
    "Back" : "Zpět",
    "Add collaborators" : "Přidat spolupracující",
    "Save" : "Uložit",
    "Create album" : "Vytvořit album",
    "Add to Album" : "Přidat do alba",
    "Add selection to album {albumName}" : "Přidat výběr do alba {albumName}",
    "Shared by" : "Nasdílel(a)",
    "Create a new album." : "Vytvořit nové album.",
    "Create new album" : "Vytvořit nové album",
    "New album" : "Nové album",
    "_%n item_::_%n photos and videos_" : ["%n položka","%n fotky a videa","%n fotek a videí","%n fotky a videa"],
    "Failed to fetch collaborators list." : "Nepodařilo se získat seznam spolupracujících.",
    "Failed to update album." : "Album se nepodařilo aktualizovat.",
    "Add people or groups who can edit your album" : "Přidejte uživatele či skupiny, kteří mohou album upravovat",
    "Search people or groups" : "Hledat uživatele nebo skupiny",
    "No recommendations. Start typing." : "Žádná doporučení. Pište.",
    "Group" : "Skupina",
    "Remove {collaboratorLabel} from the collaborators list" : "Odebrat {collaboratorLabel} ze seznamu spolupracujících",
    "Copy the public link" : "Zkopírovat veřejný odkaz",
    "Public link copied!" : "Veřejný odkaz zkopírován!",
    "Copy public link" : "Zkopírovat veřejný odkaz",
    "Delete the public link" : "Zkopírovat veřejný odkaz",
    "Create public link share" : "Vytvořit sdílení veřejným odkazem",
    "Share via public link" : "Nasdílet prostřednictvím veřejného odkazu",
    "This collection does not exist" : "Tato sbírka neexistuje",
    "An error occurred" : "Došlo k chybě",
    "No picture for this day" : "Žádný obrázek pro tento den",
    "Picture taken on this day will show up here." : "Obrázek pořízený v tento den se zobrazí zde.",
    "More photos from this day" : "Více fotek z tohoto dne",
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nepřiřazená fotka","%n nepřiřazené fotky","%n nepřiřazených fotek","%n nepřiřazené fotky"],
    "Favorite" : "Přidat do oblíbených",
    "Favorite image, open the full size \"{name}\" image" : "Zařadit obrázek mezi oblíbené, otevřít obrázek „{name}“ v plné velikosti",
    "Open the full size \"{name}\" image" : "Otevřít obrázek „{name}“ v plné velikosti",
    "Select image {imageName}" : "Vybrat obrázek {imageName}",
    "Open the \"{name}\" folder" : "Otevřít složku „{name}“",
    "Back to {folder}" : "Zpět do {folder}",
    "Go back" : "Jít zpět",
    "Share this folder" : "Sdílet tuto složku",
    "Dates" : "Data",
    "Jump to specific date in list" : "Přejít na konkrétní datum v seznamu",
    "Jump to {date}" : "Přejít na {date}",
    "Add to {destination}" : "Přidat do {destination}",
    "The destination folder is owned by {owner}" : "Cílová složka je vlastněna {owner}",
    "There are no photos or videos yet!" : "Zatím zde nejsou žádné fotky či videa!",
    "_{years} year ago_::_{years} years ago_" : ["Před {years} rokem","Před {years} roky","Před {years} lety","Před {years} roky"],
    "Enable squared photos view" : "Zapnout čtvercové zobrazení fotek",
    "Delete source directory" : "Smazat zdrojovou složku",
    "Pick folder" : "Vybrat složku",
    "Select a source folder for your media" : "Vyberte zdrojovou složku pro svá média",
    "All folders" : "Všechny složky",
    "Add a Photos source for the timelines" : "Přidat zdroj Fotek pro časové osy",
    "Add folder" : "Přidat složku",
    "Select the default upload location for your media" : "Vyberte výchozí umístění pro nahrávání vašich médií",
    "Home" : "Domů",
    "Choose default Photos upload and Albums location" : "Zvolte ýchozí umístění nahrávání fotek a alb",
    "Choose a different folder" : "Vyberte jinou složku",
    "View" : "Zobrazit",
    "Media folders" : "Složky Médií",
    "Choose the folders from where photos and videos are shown." : "Zvolte složky ze kterých zobrazovat fotky a videa.",
    "Upload folder" : "Složka pro nahrávání",
    "Choose the folder where photos and albums are uploaded to." : "Zvolte složku do které nahrávat fotky a alba.",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Unselect all" : "Zrušit výběr všeho",
    "Add photos to this album" : "Přidat fotky do tohoto alba",
    "Manage collaborators for this album" : "Spravovat spolupracující pro toto album",
    "Open actions menu" : "Otevřít nabídku akcí",
    "Edit album details" : "Upravit podrobnosti o albu",
    "Download all files in album" : "Stáhnout veškeré soubory v albu",
    "Delete album" : "Smazat album",
    "Download selected files" : "Stáhnout si označené soubory",
    "Remove selection from album" : "Odebrat vybrané z alba",
    "This album does not have any photos or videos yet!" : "Toto album zatím neobsahuje žádné fotky či videa!",
    "Add photos to {albumName}" : "Přidat fotky do {albumName}",
    "Manage collaborators" : "Spravovat spolupracující",
    "Save collaborators for this album." : "Uložit spolupracující pro toto album.",
    "Cover photo for album {albumName}" : "Foto na obálku alba {albumName}",
    "There is no album yet!" : "Zatím zde nejsou žádná alba",
    "This person could not be found" : "Tuto osobu se nepodařilo nalézt",
    "Rename person" : "Přejmenovat osobu",
    "Merge with different person" : "Sloučit s jinou osobou",
    "Download selected photos" : "Stáhnout si označené fotky",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Remove person" : "Odebrat osobu",
    "Name of this person" : "Pojmenovat tuto osobu",
    "Save." : "Uložit.",
    "Merge person" : "Sloučit osobu",
    "Move to different person" : "Přesunout k jiné osobě",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Přesunout fotku k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě"],
    "_Remove photo from person_::_Remove photos from person_" : ["Odebrat fotku z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby"],
    "This might take some time depending on the size of your photo library." : "Toto může zabrat nějakou dobu v závislosti na velikosti vaší knihovny fotek.",
    "Recognized people will show up here" : "Rozpoznaní lidé se zobrazí zde",
    "This folder does not exist" : "Tato složka neexistuje",
    "Loading folders …" : "Načítání složek…",
    "No photos in here" : "Tady nejsou žádné fotky",
    "Taken on {date} at {time}" : "Pořízeno {date} v {time}",
    "This place does not have any photos or videos yet!" : "Toto umístění zatím nemá ještě žádné fotky nebo videa!",
    "Add photos to this place" : "Přidat tomuto umístění nějaké fotky",
    "Cover photo for place {placeName}" : "Foto na obálku pro umístění {placeName}",
    "There is no place yet!" : "Zatím zde není žádné umístění!",
    "Cover photo for shared album {albumName}" : "Foto na obálku sdíleného alba {albumName}",
    "Back to tags overview" : "Zpět na přehled štítků",
    "No photos with this tag yet" : "Zatím žádné fotky s tímto štítkem",
    "No tags yet" : "Zatím žádné štítky",
    "Photos with tags will show up here" : "Fotky opatřené štítky se objeví zde",
    "Popular tags" : "Oblíbené štítky",
    "All tags" : "Všechny štítky",
    "One of the source folders does not exist" : "Jedna ze zdrojových složek neexistuje",
    "Add to album" : "Přidat do alba",
    "Delete selection" : "Smazat výběr",
    "No photos or videos in here" : "Nenacházejí se zde žádné fotky nebo videa",
    "Unassigned faces" : "Nepřiřazené obličeje",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Failed to fetch collection." : "Sbírku se nepodařilo stáhnout.",
    "Failed to fetch collections list." : "Nepodařilo se získat seznam sbírek.",
    "Failed to fetch faces list." : "Nepodařilo se získat seznam obličejů.",
    "Error fetching files" : "Chyba při získávání souborů",
    "All your media" : "Veškerá vaše média",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Sdílená alba",
    "Shared album {title}" : "Sdílené album {title}",
    "Public album {title}" : "Veřejné album {title}",
    "Tagged photos" : "Oštítkované fotky",
    "Tagged photo {title}" : "Fotka {title} opatřena štítkem",
    "{title}'s face" : "Obličej {title}",
    "{startDate} to {endDate}" : "{startDate} až {endDate}",
    "Details" : "Podrobnosti",
    "Failed to rename {oldName} to {faceName}" : "Nepodařilo se přejmenovat {oldName} na {faceName}",
    "Failed to delete {faceName}" : "Nepodařilo se smazat {faceName}",
    "Failed to delete {fileId}" : "Nepodařilo se smazat {fileId}",
    "Failed to delete {fileName}" : "Nepodařilo se smazat {fileName}",
    "Failed to set favorite state for {fileId}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileId}",
    "Failed to set favorite state for {fileName}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileName}",
    "Could not load photos folder" : "Nepodařilo se načíst složku s fotkami",
    "One of the source folders does not exists" : "Jedna ze zdrojových složek neexistuje",
    "Add" : "Přidat"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");

==> nextcloud-33.0.0-1-any.pkg.tar.zst: usr/share/webapps/nextcloud/apps/photos/l10n/cs.js <==
OC.L10N.register(
    "photos",
    {
    "Public link" : "Veřejný odkaz",
    "Photos" : "Fotky",
    "On This Day" : "V tento den",
    "Your memories under your control" : "Vaše vzpomínky pod vaší kontrolou",
    "All media" : "Veškerá média",
    "Videos" : "Videa",
    "Albums" : "Alba",
    "Collaborative albums" : "Alba pro spolupráci",
    "People" : "Lidé",
    "Folders" : "Složky",
    "Favorites" : "Oblíbené",
    "On this day" : "V tento den",
    "Shared with you" : "Sdíleno s vámi",
    "Tags" : "Štítky",
    "Places" : "Místa",
    "Map" : "Mapa",
    "Photos settings" : "Nastavení pro Fotky",
    "Mark selection as favorite" : "Označit vybrané jako oblíbené",
    "Add selection to favorites" : "Přidat vybrané do oblíbených",
    "Remove selection from favorites" : "Odebrat vybrané z oblíbených",
    "This name is already in use." : "Tento název už je využíván.",
    "\"{char}\" is not allowed inside a filename." : "„{char}“ není v názvu souboru možné použít.",
    "Invalid filename." : "Neplatný název souboru.",
    "Name of the album" : "Název alba",
    "Location of the album" : "Umístění alba",
    "Back" : "Zpět",
    "Add collaborators" : "Přidat spolupracující",
    "Save" : "Uložit",
    "Create album" : "Vytvořit album",
    "Add to Album" : "Přidat do alba",
    "Add selection to album {albumName}" : "Přidat výběr do alba {albumName}",
    "Shared by" : "Nasdílel(a)",
    "Create a new album." : "Vytvořit nové album.",
    "Create new album" : "Vytvořit nové album",
    "New album" : "Nové album",
    "_%n item_::_%n photos and videos_" : ["%n položka","%n fotky a videa","%n fotek a videí","%n fotky a videa"],
    "Failed to fetch collaborators list." : "Nepodařilo se získat seznam spolupracujících.",
    "Failed to update album." : "Album se nepodařilo aktualizovat.",
    "Add people or groups who can edit your album" : "Přidejte uživatele či skupiny, kteří mohou album upravovat",
    "Search people or groups" : "Hledat uživatele nebo skupiny",
    "No recommendations. Start typing." : "Žádná doporučení. Pište.",
    "Copy the public link" : "Zkopírovat veřejný odkaz",
    "Public link copied!" : "Veřejný odkaz zkopírován!",
    "Copy public link" : "Zkopírovat veřejný odkaz",
    "Delete the public link" : "Zkopírovat veřejný odkaz",
    "Create public link share" : "Vytvořit sdílení veřejným odkazem",
    "Share via public link" : "Nasdílet prostřednictvím veřejného odkazu",
    "This collection does not exist" : "Tato sbírka neexistuje",
    "An error occurred" : "Došlo k chybě",
    "No picture for this day" : "Žádný obrázek pro tento den",
    "Picture taken on this day will show up here." : "Obrázek pořízený v tento den se zobrazí zde.",
    "More photos from this day" : "Více fotek z tohoto dne",
    "_%n photos_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "_%n unassigned photo_::_%n unassigned photos_" : ["%n nepřiřazená fotka","%n nepřiřazené fotky","%n nepřiřazených fotek","%n nepřiřazené fotky"],
    "Favorite" : "Přidat do oblíbených",
    "Favorite image, open the full size \"{name}\" image" : "Zařadit obrázek mezi oblíbené, otevřít obrázek „{name}“ v plné velikosti",
    "Open the full size \"{name}\" image" : "Otevřít obrázek „{name}“ v plné velikosti",
    "Select image {imageName}" : "Vybrat obrázek {imageName}",
    "Open the \"{name}\" folder" : "Otevřít složku „{name}“",
    "Go back" : "Jít zpět",
    "Select a custom date range" : "Vyberte uživatelsky určené datumové rozmezí",
    "Select a date range" : "Vybrat datumové rozmezí",
    "Date range" : "Datumové rozmezí",
    "Select filters" : "Vybrat filtry",
    "Dates" : "Data",
    "Jump to specific date in list" : "Přejít na konkrétní datum v seznamu",
    "Jump to {date}" : "Přejít na {date}",
    "Add to {destination}" : "Přidat do {destination}",
    "The destination folder is owned by {owner}" : "Cílová složka je vlastněna {owner}",
    "There are no photos or videos yet!" : "Zatím zde nejsou žádné fotky či videa!",
    "_{years} year ago_::_{years} years ago_" : ["Před {years} rokem","Před {years} roky","Před {years} lety","Před {years} roky"],
    "Squared photos view" : "Čtvercové zobrazení fotek",
    "Delete source directory" : "Smazat zdrojovou složku",
    "Pick folder" : "Vybrat složku",
    "Select a source folder for your media" : "Vyberte zdrojovou složku pro svá média",
    "Media folders" : "Složky Médií",
    "Choose the folders from where photos and videos are shown." : "Zvolte složky ze kterých zobrazovat fotky a videa.",
    "All folders" : "Všechny složky",
    "Add a Photos source for the timelines" : "Přidat zdroj Fotek pro časové osy",
    "Add folder" : "Přidat složku",
    "Home" : "Domů",
    "Select the default upload location for your media" : "Vyberte výchozí umístění pro nahrávání vašich médií",
    "Upload folder" : "Složka pro nahrávání",
    "General" : "Obecné",
    "_%n photo_::_%n photos_" : ["%n fotka","%n fotky","%n fotek","%n fotky"],
    "Unselect all" : "Zrušit výběr všeho",
    "Add photos to this album" : "Přidat fotky do tohoto alba",
    "Manage collaborators for this album" : "Spravovat spolupracující pro toto album",
    "Open actions menu" : "Otevřít nabídku akcí",
    "Edit album details" : "Upravit podrobnosti o albu",
    "Download all files in album" : "Stáhnout veškeré soubory v albu",
    "Delete album" : "Smazat album",
    "Download selected files" : "Stáhnout si označené soubory",
    "Remove selection from album" : "Odebrat vybrané z alba",
    "This album does not have any photos or videos yet!" : "Toto album zatím neobsahuje žádné fotky či videa!",
    "Add photos to {albumName}" : "Přidat fotky do {albumName}",
    "Manage collaborators" : "Spravovat spolupracující",
    "Save collaborators for this album." : "Uložit spolupracující pro toto album.",
    "Cover photo for album {albumName}" : "Foto na obálku alba {albumName}",
    "There is no album yet!" : "Zatím zde nejsou žádná alba",
    "This person could not be found" : "Tuto osobu se nepodařilo nalézt",
    "Rename person" : "Přejmenovat osobu",
    "Merge with different person" : "Sloučit s jinou osobou",
    "Download selected photos" : "Stáhnout si označené fotky",
    "Remove from favorites" : "Odebrat z oblíbených",
    "Remove person" : "Odebrat osobu",
    "Name of this person" : "Pojmenovat tuto osobu",
    "Save." : "Uložit.",
    "Merge person" : "Sloučit osobu",
    "Move to different person" : "Přesunout k jiné osobě",
    "_Move photo to a different person_::_Move photos to a different person_" : ["Přesunout fotku k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě","Přesunout fotky k jiné osobě"],
    "_Remove photo from person_::_Remove photos from person_" : ["Odebrat fotku z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby","Odebrat fotky z osoby"],
    "This might take some time depending on the size of your photo library." : "Toto může zabrat nějakou dobu v závislosti na velikosti vaší knihovny fotek.",
    "Recognized people will show up here" : "Rozpoznaní lidé se zobrazí zde",
    "This folder does not exist" : "Tato složka neexistuje",
    "Loading folders…" : "Načítání složek …",
    "No photos in here" : "Tady nejsou žádné fotky",
    "Taken on {date} at {time}" : "Pořízeno {date} v {time}",
    "This place does not have any photos or videos yet!" : "Toto umístění zatím nemá ještě žádné fotky nebo videa!",
    "Add photos to this place" : "Přidat tomuto umístění nějaké fotky",
    "Cover photo for place {placeName}" : "Foto na obálku pro umístění {placeName}",
    "There is no place yet!" : "Zatím zde není žádné umístění!",
    "Cover photo for shared album {albumName}" : "Foto na obálku sdíleného alba {albumName}",
    "Back to tags overview" : "Zpět na přehled štítků",
    "No photos with this tag yet" : "Zatím žádné fotky s tímto štítkem",
    "No tags yet" : "Zatím žádné štítky",
    "Photos with tags will show up here" : "Fotky opatřené štítky se objeví zde",
    "Popular tags" : "Oblíbené štítky",
    "All tags" : "Všechny štítky",
    "Create new album from filters" : "Vytvořit nové album z filtrů",
    "One of the source folders does not exist" : "Jedna ze zdrojových složek neexistuje",
    "Add to album" : "Přidat do alba",
    "Delete selection" : "Smazat výběr",
    "No photos or videos in here" : "Nenacházejí se zde žádné fotky nebo videa",
    "Unassigned faces" : "Nepřiřazené obličeje",
    "Failed to fetch collection." : "Sbírku se nepodařilo stáhnout.",
    "Failed to fetch collections list." : "Nepodařilo se získat seznam sbírek.",
    "Failed to fetch faces list." : "Nepodařilo se získat seznam obličejů.",
    "Error fetching files" : "Chyba při získávání souborů",
    "All your media" : "Veškerá vaše média",
    "Album {title}" : "Album {title}",
    "Shared Albums" : "Sdílená alba",
    "Shared album {title}" : "Sdílené album {title}",
    "Public album {title}" : "Veřejné album {title}",
    "Tagged photos" : "Oštítkované fotky",
    "Tagged photo {title}" : "Fotka {title} opatřena štítkem",
    "{title}'s face" : "Obličej {title}",
    "Last week" : "Uplynulý týden",
    "Last Month" : "Uplynulý měsíc",
    "Custom…" : "Uživatelsky určené …",
    "{startDate} to {endDate}" : "{startDate} až {endDate}",
    "Details" : "Podrobnosti",
    "Failed to add {fileBaseName} to collection {collectionFileName}" : "Nepodařilo se přidat {fileBaseName} do sbírky {collectionFileName}",
    "Failed to delete {fileBaseName}" : "Nepodařilo se smazat {fileBaseName}",
    "Failed to create {collectionFileName}" : "Nepodařilo se vytvořit {collectionFileName}",
    "Failed to rename {currentCollectionFileName} to {newCollectionFileName}" : "Nepodařilo se přejmenovat {currentCollectionFileName} na {newCollectionFileName}",
    "Failed to update properties of {collectionFileName} with {properties}" : "Nepodařilo se zaktualizovat vlastnosti {collectionFileName} s {properties}",
    "Delete collection" : "Smazat sbírku",
    "Leave shared album" : "Opustit sdílené album",
    "Are you sure you want to delete {collectionName}? This action cannot be undone." : "Opravdu chcete {collectionName} smazat? Tuto akci nepůjde vzít zpět.",
    "Failed to delete {collectionFileName}" : "Nepodařilo se smazat {collectionFileName}",
    "Cancel" : "Zrušit",
    "Confirm" : "Potvrdit",
    "Failed to move {fileBaseName} to person {faceName}" : "Nepodařil ose přesunout {fileBaseName} k osobě {faceName}",
    "Failed to remove {fileBaseName}" : "Nepodařilo se odebrat {fileBaseName}",
    "Failed to rename {oldName} to {faceName}" : "Nepodařilo se přejmenovat {oldName} na {faceName}",
    "Failed to delete {faceName}" : "Nepodařilo se smazat {faceName}",
    "Failed to delete {fileId}" : "Nepodařilo se smazat {fileId}",
    "Failed to delete {fileName}" : "Nepodařilo se smazat {fileName}",
    "Failed to set favorite state for {fileId}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileId}",
    "Failed to set favorite state for {fileName}" : "Nepodařilo se nastavit stav zařazení mezi oblíbené pro {fileName}",
    "Could not load photos folder" : "Nepodařilo se načíst složku s fotkami",
    "Group" : "Skupina",
    "Remove {collaboratorLabel} from the collaborators list" : "Odebrat {collaboratorLabel} ze seznamu spolupracujících",
    "Back to {folder}" : "Zpět do {folder}",
    "Share this folder" : "Sdílet tuto složku",
    "Enable squared photos view" : "Zapnout čtvercové zobrazení fotek",
    "Choose default Photos upload and Albums location" : "Zvolte ýchozí umístění nahrávání fotek a alb",
    "Choose a different folder" : "Vyberte jinou složku",
    "View" : "Zobrazit",
    "Choose the folder where photos and albums are uploaded to." : "Zvolte složku do které nahrávat fotky a alba.",
    "Loading folders …" : "Načítání složek …",
    "Add" : "Přidat",
    "Loading folders …" : "Načítání složek …"
},
"nplurals=4; plural=(n == 1 && n % 1 == 0) ? 0 : (n >= 2 && n <= 4 && n % 1 == 0) ? 1: (n % 1 != 0 ) ? 2 : 3;");
